"use strict";
// Copyright 2016-2018, Pulumi Corporation.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const pulumi = require("@pulumi/pulumi");
const subscription = require("../subscription");
/**
 * Creates a new subscription to the given blob using the callback provided, along with optional
 * options to control the behavior of the subscription.
 */
function onBlobEvent(name, account, args, opts) {
    return __awaiter(this, void 0, void 0, function* () {
        args = args || {};
        let path;
        if (args.path) {
            path = args.path;
        }
        else if (args.containerName) {
            const prefix = args.filterPrefix || "";
            const suffix = args.filterSuffix || "";
            path = pulumi.all([args.containerName, prefix, suffix]).apply(([cn, pr, su]) => cn + `/${pr}{blobName}${su}`);
        }
        else {
            throw new pulumi.RunError("Either [path] or [containerName] must be present in [args]");
        }
        // The blob binding does not store the storage connection string directly.  Instead, the
        // connection string is put into the app settings (under whatever key we want). Then, the
        // .connection property of the binding contains the *name* of that app setting key.
        const bindingConnectionKey = "BindingConnectionAppSettingsKey";
        const bindings = pulumi.output(path).apply(p => {
            const blobBinding = {
                name: "blob",
                type: "blobTrigger",
                direction: "in",
                dataType: "binary",
                path: p,
                connection: bindingConnectionKey,
            };
            return [blobBinding];
        });
        // Place the mapping from the well known key name to the storage account connection string in
        // the 'app settings' object.
        const appSettingsOutput = args.appSettings || pulumi.output({});
        args.appSettings = pulumi.all([appSettingsOutput, account.primaryConnectionString]).apply(([appSettings, connectionString]) => {
            appSettings[bindingConnectionKey] = connectionString;
            return appSettings;
        });
        return new BlobEventSubscription(name, account, bindings, args, opts);
    });
}
exports.onBlobEvent = onBlobEvent;
class BlobEventSubscription extends subscription.EventSubscription {
    constructor(name, account, bindings, args, options) {
        super("azure-serverless:account:BlobEventSubscription", name, bindings, args, options);
        this.account = account;
    }
}
exports.BlobEventSubscription = BlobEventSubscription;
//# sourceMappingURL=account.js.map